#!/usr/bin/env python
#file: rnalib/format/clustal.py


def aln_to_clustal(aln):
    """Return string with alignment in clustal format

    aln -- Alignment object

    Cuts sequences in pieces of 55 chars each.
    It relabels all the sequences and they are returned
    in an arbitrary order.
    """
    seq_parts = []
    for name, seq in aln.NamedSeqs.items():
        #print len(seq)
        seq_parts.append([])
        begin = 0
        end = 55
        while begin < len(seq):
            seq_parts[-1].append((name, seq[begin:end]))
            begin += 55
            end += 55

    lines = []

    first = "CLUSTAL W (1.83) clustalw format for given alignment\n"
    lines.append(first)

    for part_idx in range(len(seq_parts[0])):
        for seq_idx in range(len(seq_parts)):
            name, seq = seq_parts[seq_idx][part_idx]
            label = "seq_%s"%(seq_idx)
            num_spaces = 18 - len(label)
            lines.append(label + num_spaces*' ' + str(seq))
        lines.append('\n')

    return '\n'.join(lines)

