#!/usr/bin/env python
# Author: Greg Caporaso (gregcaporaso@gmail.com)
# make_py_file.py

"""
This is a script which will add headers and footers to new python files
and make them executable. 
"""

from sys import exit
from os import popen
from os.path import exists
from time import strftime
from optparse import OptionParser

def parse_command_line_parameters():
    """ Parses command line arguments """
    result = OptionParser()

    # A binary 'verbose' flag
    result.add_option('-v','--verbose',action='store_true',dest='verbose')
    result.add_option('-s','--script',action='store_true',dest='script')
    # An example string option
    #result.add_option('-i','--input_dir',action='store',\
    #                  type='string',dest='input_dir')

    result.set_defaults(verbose=False)
    return result.parse_args()

script_block =\
"""from optparse import OptionParser

def parse_command_line_parameters():
    \"\"\" Parses command line arguments \"\"\"
    result = OptionParser()

    # A binary 'verbose' flag
    result.add_option('-v','--verbose',action='store_true',dest='verbose')

    # An example string option
    #result.add_option('-i','--input_dir',action='store',\\
    #                  type='string',dest='input_dir')

    # Set default values here if they should be other than None
    result.set_defaults(verbose=False)
    return result.parse_args()

"""

if __name__ == "__main__":
    
    opts,args = parse_command_line_parameters()
    verbose = opts.verbose
    script = opts.script
    filenames = args

    # Check to see if any of the files which were requested to be created
    # already exist -- if they do, print a message and exit
    if True in map(exists,filenames):
        print '\n'.join(["Some of the filenames you requested already exist.",\
            "    Please delete extant file(s) and rerun script if ",\
            "    they should be overwritten. Otherwise edit the list.",\
            "Creating no files and exiting..."])
        exit(1) 

    for filename in filenames:
        test_file = filename.startswith('test')

        # Create the header data
        lines = ['#!/usr/bin/env python',\
            ' '.join(['#',filename]),\
            '',\
            '"""\nAuthor: Sandra Smit (S.Smit@few.vu.nl)\n',\
            'Revision History:',\
            ''.join(['File created on ',strftime('%d %b %Y'),'.']),'',\
            '"""\n'\
            'from __future__ import division']

        # If this is a test file, add the requiste import statement
        if test_file:
            lines.append('from cogent.util.unit_test import TestCase, main')
        elif script:
            lines.append(script_block)

        # Create the footer data
        # File will be executable
        lines += ['','','','if __name__ == "__main__":']
        if test_file:
            # Run unittest.main() if test file
            lines.append('    main()')
        elif script:
            lines.append('    opts,args = parse_command_line_parameters()')
        else:
            # Running the file does nothing by default if not a test file
            lines.append('    pass')

        # Open the new file for writing and write it.
        f = open(filename,'w')
        f.write('\n'.join(lines))
        f.close()

        # Change the permissions on the new file to make it executable
        chmod_string = ' '.join(['chmod 755',filename])
        popen(chmod_string)
