#!/usr/bin/env python
# mc_annotate.py

"""
Author: Sandra Smit (Sandra.Smit@colorado.edu)

Revision History:
File created on 30 Jul 2007.

"""
from __future__ import division
from cogent.parse.rnaview import Base, BasePair, BasePairs

SAENGER = ['I','II','III','IV','V','VI','VII','VIII','IX','X',\
    'XI','XII','XIII','XIV','XV',\
    'XVI','XVII','XVIII','XIX','XX',\
    'XXI','XXII','XXIII','XXIV','XXV',\
    'XXVI','XXVII','XXVIII']

def is_saenger(item):
    if item in SAENGER:
        return True
    return False

def parse_base(base):
    chain_id, res_id, res_type = base.split(',')
    rna_dna, res_name = res_type.split(':')
    #descr, res_name = base.strip().split(':')
    #chain_id, res_id, res_type = descr[0], descr[1:-1], descr[-1]
    result = Base(chain_id, res_id, res_name)
    return result

def parse_annotation(ann):
    parts = ann.split()
    #if len(parts) != 5:
    #    raise ValueError("Expected five parts, got %s"%(len(parts)))
    pairing_type = parts[0]
    conformation = parts[1]
    orientation = parts[2]
    saenger = ' '.join(parts[3:-1])
    edges = parts[-1]
    
    return pairing_type, edges, orientation, conformation, saenger

def parse_bp(line):
    """Parse single line (=single base pair)

    Only parse RNA residues
    skip DNA, skip 'adjacent_5p'
    """
    if not line.strip():
        return None
    #print line.strip()
    upstream_data, downstream_data, ann_data = line.rstrip().split('!!')
    base_info, pairing_info = ann_data.rsplit(':',1)
    #upstream_data, downstream_data = base_info.strip('{').split("->")
    annotation = pairing_info.strip(' }')
    if not annotation.startswith('pairing'):
        return None
    else:
        upstream_base = parse_base(upstream_data)
        downstream_base = parse_base(downstream_data)
        pairing_type, edges, orientation, conformation, saenger =\
            parse_annotation(annotation)
        result = BasePair(upstream_base, downstream_base, edges, orientation,\
            conformation, saenger)
        return result

def McAnnotateParser(lines):
    result = BasePairs()
    for line in lines:
        # skip empty lines and comments
        if not line.strip() or line.startswith('#'):
            continue
        bp = parse_bp(line)
        if bp is not None:
            result.append(bp)
    #print result
    return result

if __name__ == "__main__":
    from sys import argv
    print McAnnotateParser(open(argv[1]))
