#!/usr/bin/env python

from cogent.util.unit_test import TestCase, main
from rnalib.parse.rdb_dcse import *

class RdbDCSEParserTests(TestCase):

    def test_get_complete(self):
        self.assertEqual(get_complete("- - -G6'- -"), ["G6'"])
        self.assertEqual(get_complete("G8-"), [])
        self.assertEqual(get_complete("- -G6'- - - -G7 -"), ["G6'","G7"])
        self.assertEqual(get_complete("14- - - - - - -G"), [])
        self.assertEqual(get_complete("-E23_10'-E23_12 -"),\
            ["E23_10'","E23_12"])

    def test_get_left_middle_right(self):
        rdb = " U[U G U U G]G G G[C G A C A]A[A G U A G]C"
        num = " - - -G6 - - - - - - -G6'- - - -G7 - - - -"
        l,m,r = get_left_middle_right(num, 18, rdb)
        self.assertEqual(l, ["G6"])
        self.assertEqual(m, ["G6'"])
        self.assertEqual(r, ["G7"])
        
        rdb = " A C[G G A - G G A^G]U -[A C]A A "
        num = " - - - - - - G7' - - G8- - G9- - "
        l,m,r = get_left_middle_right(num, 4, rdb)
        self.assertEqual(l, [])
        self.assertEqual(m, ["G7'"])
        self.assertEqual(r, ["G8"])
        l,m,r = get_left_middle_right(num, 18, rdb)
        self.assertEqual(l, ["G7'"])
        self.assertEqual(m, [])
        self.assertEqual(r, ["G8"])
        l,m,r = get_left_middle_right(num, 24, rdb)
        self.assertEqual(l, ["G8"])
        self.assertEqual(m, ["G9"])
        self.assertEqual(r, [])

        rdb = " C A A[C]G G A C"
        num = " - - -P23_7' - -"
        l,m,r = get_left_middle_right(num, 6, rdb)
        self.assertEqual(l, [])
        self.assertEqual(m, ["P23_7'"])
        self.assertEqual(r, [])

        rdb = euk_rdb
        num = euk_num
        l,m,r = get_left_middle_right(num, 6, rdb)
        self.assertEqual(l, [])
        self.assertEqual(m, ["E23_4'"])
        self.assertEqual(r, ["E23_8"])
        l,m,r = get_left_middle_right(num, 71, rdb)
        self.assertEqual(l, ["E23_8"])
        self.assertEqual(m, ["E23_9"])
        self.assertEqual(r, ["E23_10"])
        l,m,r = get_left_middle_right(num, 106, rdb)
        self.assertEqual(l, ["E23_11"])
        self.assertEqual(m, ["E23_10'"])
        self.assertEqual(r, ["E23_12"])

euk_rdb=\
""" - - -[o o o o o o]- - - - o o o[o o o]o o - o o o o o o o o o - - - - o[o o]- o o[o o]o - -[o o o o]o o -[o o]o[o o o]- - - - - """
euk_num=\
""" - - - - - - E23_4'- - - - - - - - E23_8 - - - - - - - - - - - - - - - - - E23_9 - -E23_10 - -E23_11 - - - -E23_10'-E23_12 - - - """


rdb_seq=\
"U C[G G U U G]G G G[U G A C C^U C G G A G]A - A U C[C U C - C G A]A U -[G A]U - - - - - - - - - A C U A A - - U A[U C]- - U U A A C G G A -"


helix=\
"- - - -G6 - - - - - - -G6'- - - -G7 - - - - - - - - - - - - G7' - - G8- - G9- - - - - -G14- - - - - - -G14' - - - - -G9'- - - - - G8' - - -"



" U - - - - - - - - - - - - - -[U A G A]U A G A[U U U A]A G U U"
" - - - -E6 - - - - - - - - - - - - - - - - - - - -E6'- - - - -"

""" U[U G U U G]G G G[C G A C A]A[A G U A G]C - - A U A U U A A - C[C U A C U]U[A]- - -[A A]U - C U[U U]U - G U[U]U G"""
""" - - -G6 - - - - - - -G6'- - - -G7 - - - - - - - - - - - - - - - - - - - G7' - - G8- - G9- - - - -G9'- - - - G8' -"""

if __name__ == "__main__":
    main()
