#!/usr/bin/env python
# bpseq_to_vienna.py

"""Script to extract sequence and structure from .bpseq files 
from the CRW database and store in a FASTA formatted file.

Right now writes a file like this:
>filename
sequence
vienna structure (without pseudoknots)

Author: Sandra Smit (Sandra.Smit@colorado.edu)

Revision History:
File created on 24 Jan 2007.
"""
from __future__ import division
import sys
import os
from optparse import OptionParser
from cogent.parse.bpseq import BpseqParser, BpseqParseError

def parse_command_line_parameters():
    """ Parses command line arguments """
    usage = "usage: %prog [options] bpseq_filename"
    result = OptionParser(usage=usage)

    result.add_option('-d','--directory',action='store', type='string',\
        dest='directory',\
        help="apply to all .bpseq files in the directory")
    result.add_option('-r','--rule',action='store', type='string',\
        dest='rule',\
        help="rule for removing pseudoknots, options: first or majority; default is majority")
    result.add_option('-o','--out',action='store', type='string',\
        dest='out', help="name of output file; has to be specified")

    result.set_defaults(directory=None)
    result.set_defaults(rule='majority')
    result.set_defaults(out=None)
    return result.parse_args()


if __name__ == "__main__":
    opts,arg = parse_command_line_parameters()
    if opts.out is None:
        print "Specify a name for the output file."
        print "Run 'python dcse_to_vienna.py -h' for more help"
        sys.exit()
    if opts.directory is None and arg == []:
        print "Specify either a filename or a whole directory."
        print "Run 'python dcse_to_vienna.py -h' for more help"
        sys.exit()
    
    filenames = []
    if opts.directory is not None:
        for root, dirs, files in os.walk(opts.directory):
            for file in files:
                if file.endswith('.bpseq'):
                    filenames.append('/'.join([opts.directory,file]))
    else:
        filenames.append(arg[0])

    out_file = open(opts.out,'w')
   
    for f in filenames:

        #short = f.split('/')[-1].rsplit('.',1)[0]
        try:
            seq, orig_pairs = BpseqParser(open(f))
        except BpseqParseError:
            continue
        if orig_pairs.hasPseudoknots():
            nested = orig_pairs.nested(rule=opts.rule)
        else:
            nested = orig_pairs
        vienna_no_pseudo = nested.toVienna(len(seq))

        assert len(seq) == len(vienna_no_pseudo)

        out_file.write(">"+seq.Info.Filename+'\n')
        out_file.write(str(seq)+'\n')
        out_file.write(vienna_no_pseudo+'\n')
