#!/usr/bin/env python
# pdb_util.py

"""
Author: Sandra Smit (Sandra.Smit@colorado.edu)

Revision History:
File created on 06 Jan 2007.

"""
from __future__ import division
from string import strip
from cogent.parse.record_finder import DelimitedRecordFinder

# =============================================================================
# PDB INFO PARSER
# =============================================================================

def empty_or_comment(line):
    if line.startswith('#'):
        return True
    if (not line) or line.isspace():
        return True
    return False

info_finder = DelimitedRecordFinder('//', ignore=empty_or_comment,\
    keep_delimiter=False)

def pdb_info_parser(lines):
    for rec in info_finder(lines):
        result = {}
        for line in rec:
            label, content = line.split(':')
            if label == 'PDB':
                value = dict(zip(['ID','RESOLUTION'],\
                    map(strip, content.split(','))))
            elif label == 'FAMILY':
                value = map(strip, content.split(','))
            elif label == 'CHAINS':
                value = content.strip(';')
            elif label == 'LENGTH':
                ann, seq = map(strip, content.split(','))
                value = {'ANN': ann, 'SEQ': int(seq)}
            elif label == 'CONFLICT' and ';' in content:
                res = {}
                conflicts = content.split(';')
                for c in conflicts:
                    if not c:
                        continue
                    res_up, chain_up, res_down, chain_down =\
                        c.lstrip().split('-')
                    res[(chain_up, res_up, chain_down, res_down)] = None
                value = res
            else:
                value = None
            result[label] = value
        if not result['PDB']['ID']:
            continue
        yield result



if __name__ == "__main__":
    from sys import argv
    pdb_info_file = argv[1]
    counter = 0
    for rec in pdb_info_parser(open(pdb_info_file)):
        counter += 1
        print rec
    print counter
