#!/usr/bin/env python

from cogent.parse.record_finder import LineGrouper
from cogent.app.vienna_package import RNAfold, RNAsubopt
from cogent.struct.rna2d import Vienna

two_at_the_time = LineGrouper(2)

def just_seqs_parser(lines, struct_constructor=Vienna):
    return [(seq, struct_constructor(struct))\
        for seq, struct in two_at_the_time(lines)]

def mfe_structs_from_seqs(seqs, struct_constructor=Vienna, noLP=False):
    """Returns a list of MFE Vienna structures calculated for the sequences.

    seqs: list of sequences (no labels!), expects sequences as simple strings
    """
    r = RNAfold()
    if noLP is True:
        r.Parameters['-noLP'].on()
    #print r.BaseCommand
    res = r(seqs)
    output = res['StdOut'].readlines()
    structures = [struct for (seq, struct) in\
        just_seqs_parser(output, struct_constructor)]
    res.cleanUp()
    #print structures
    return structures

def subopt_structs_from_seqs(seqs, struct_constructor=Vienna,\
    energy_range=1, noLP=False, sample_ensemble=None):
    """Returns a list of suboptimal structures calculated by RNAsubopt

    seqs: list of sequences (no labels)
    """
    structures = []
    r = RNAsubopt()
    if noLP is True:
        r.Parameters['-noLP'].on()
    if sample_ensemble is not None:
        r.Parameters['-p'].on(sample_ensemble)
    #print r.BaseCommand
    res = r(seqs)
    for line in res['StdOut'].readlines():
        try:
            s = Vienna(line.strip())
            #print 'struct found:', line.strip()
            structures.append(s)
        except ValueError:
            #print 'NOT', line.strip()
            pass
    res.cleanUp()
    return structures



if __name__ == "__main__":
    seqs = ['UAGCUAGCUGACUGAUCG', 'UAGCU-UAGCUUGUG--','AC-UGCUA-UGACUAG--UG']
    print subopt_structs_from_seqs(seqs)
