#!/usr/bin/env python
# hist.py

"""
Author: Sandra Smit (Sandra.Smit@colorado.edu)

Revision History:
File created on 24 Apr 2007.

"""
from __future__ import division
from Numeric import searchsorted, array, concatenate, argsort, sort, arange
from matplotlib.pylab import show, bar
from cogent.core.usage import Freqs
from cogent.util.misc import InverseDictMulti

def histogram(a, bins):
    n = searchsorted(sort(a), bins)
    n = concatenate([n, [len(a)]])
    return n[1:]-n[:-1]

def get_elements_in(a, bins):
    asort = argsort(a)
    h = histogram(a, bins)
    return [asort[sum(h[0:i]):sum(h[0:i+1])] for i in range(len(bins))]

def get_values(parts, col_idx, constructor=float):
    col_idx = int(col_idx)
    if constructor:
        return array(map(constructor,[p[col_idx] for p in parts]))
    else:
        return [p[col_idx] for p in parts]

def simple_bar(data, bins, width=1):
    h = histogram(data, bins)
    #print h
    bar(bins, h, width=width)
    show()

def mode(data, from_hist=False, bins=None):
    if not from_hist:
        f = Freqs(data)
        g = InverseDictMulti(f)
        print f
        print g
        return g[max(g.keys())]
    elif from_hist and bins:
        h = histogram(data, bins)
        print h
        max_count = -1
        max_bins = []
        for idx, i in enumerate(h):
            if i < max_count:
                continue
            elif i == max_count:
                max_bins.append(idx)
            else:
                max_count = i
                max_bins = [idx]
        return max_bins
    else:
        raise ValueError("Need bins to calculate a histogram")

if __name__ == "__main__":
    a = [1, 4, 2, 3, 5, 4, 3, 5, 6, 7, 4, 5, 1]
    print mode(a)
    print mode(a, from_hist=True, bins=arange(1,10,1))
    pass
